@@ -1,7 +1,12 @@
 """Sphinx demo."""
 from pathlib import Path
+import sys
 
-__version__ = '0.0.2'
+if sys.platform == 'win32':
+    import asyncio
+    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
+
+__version__ = '0.0.4'
 __version_full__ = __version__
 
 
